@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import locale
 
 # High performance method for English (no translation needed)
@@ -21,33 +23,30 @@ if loc is None or loc.startswith("en") or loc == "C":
 
 else:
     import gettext
-    import os
+    import sys
 
-    # If not installed with setuptools, this might not be available
-    try:
-        import pkg_resources
-    except ImportError:
-        pkg_resources = None  # type: ignore[assignment]
-
-    local_dir = os.path.basename(__file__)
+    if sys.version_info < (3, 9):
+        from importlib_resources import as_file, files
+    else:
+        from importlib.resources import as_file, files
 
     def get_translation_for(package_name: str) -> gettext.NullTranslations:  # type: ignore[misc]
-        """Find and return gettext translation for package
-        (Try to find folder manually if setuptools does not exist)
         """
+        Find and return gettext translation for package
+        """
+        assert loc is not None
 
         if "." in package_name:
             package_name = ".".join(package_name.split(".")[:-1])
+
         localedir = None
 
-        if pkg_resources is None:
-            mydir = os.path.join(local_dir, "i18n")
-        else:
-            mydir = pkg_resources.resource_filename(package_name, "i18n")
+        with as_file(files(package_name) / "i18n") as mydir:
+            for localedir in mydir, None:
+                localefile = gettext.find(package_name, localedir, languages=[loc])
+                if localefile:
+                    break
 
-        for localedir in mydir, None:
-            localefile = gettext.find(package_name, localedir)
-            if localefile:
-                break
-
-        return gettext.translation(package_name, localedir=localedir, fallback=True)
+            return gettext.translation(
+                package_name, localedir=localedir, languages=[loc], fallback=True
+            )
